The single comparison_scores() row belonging to the winning model,
including its scoringutils metrics, selection score, and retrospective fit
timing, rather than the whole table.
Arguments
- nc
A
nowcast_classreturned byauto_nowcast().
The single comparison_scores() row belonging to the winning model,
including its scoringutils metrics, selection score, and retrospective fit
timing, rather than the whole table.
A nowcast_class returned by auto_nowcast().