Returns all estimated parameters as a long data frame with credible intervals derived from the Laplace approximation posterior precision matrix.
Details
tidy() on a nowcast gives you the nowcast – the predicted counts, via
tbl.now's method for the broom generic. This function gives you the
parameters. They are different questions, and this package used to answer
the second one under the first one's name.
Examples
if (requireNamespace("tbl.now", quietly = TRUE)) {
# nc <- nowcast(data, model())
# parameters(nc)
}
#> NULL